package Task::BeLike::MELO;
{
  $Task::BeLike::MELO::VERSION = '0.011';
}
# ABSTRACT: All the stuff I install with a fresh perl

use strict;
use warnings;

1;


=head1 SYNOPSYS

    cpan Task::BeLike::MELO
    # Now grab a cup of tea, this will take a while..

=head1 DESCRIPTION

This task will install all the modules that I usually like to have around,
in one fell swoop.

It will take a while. Seriously.

=cut
